# Generated by Django 3.2.5 on 2021-10-04 19:34

from django.db import migrations
import django.db.models.deletion
import mptt.fields


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0030_remove_datatransformer_parent'),
    ]

    operations = [
        migrations.AddField(
            model_name='datatransformer',
            name='parent',
            field=mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='data.datatransformer'),
        ),
    ]
