# Generated by Django 3.2.4 on 2021-07-12 20:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0010_auto_20210712_2038'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pigpio',
            name='channel_index',
        ),
        migrations.RemoveField(
            model_name='pipicoanalogio',
            name='channel_index',
        ),
    ]
