# Generated by Django 3.2.5 on 2021-10-05 21:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0032_alter_datatransformer_accessory'),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name='hardwaredatatransformer',
            name='data_hardwa_id_c5fb61_idx',
        ),
        migrations.RemoveIndex(
            model_name='hardwarestats',
            name='data_hardwa_id_5b03a1_idx',
        ),
        migrations.AlterField(
            model_name='datatransformer',
            name='type',
            field=models.CharField(blank=True, default=None, max_length=15, null=True),
        ),
        migrations.RemoveField(
            model_name='hardwaredatatransformer',
            name='hardware',
        ),
        migrations.AddField(
            model_name='hardwaredatatransformer',
            name='hardware',
            field=models.ManyToManyField(to='data.Channel'),
        ),
        migrations.RemoveField(
            model_name='hardwarestats',
            name='hardware',
        ),
        migrations.AddField(
            model_name='hardwarestats',
            name='hardware',
            field=models.ManyToManyField(to='data.Channel'),
        ),
        migrations.AddIndex(
            model_name='hardwaredatatransformer',
            index=models.Index(fields=['id', 'data_transformer'], name='data_hardwa_id_d8bcf2_idx'),
        ),
        migrations.AddIndex(
            model_name='hardwarestats',
            index=models.Index(fields=['id'], name='data_hardwa_id_4060f5_idx'),
        ),
    ]
