# Generated by Django 3.2.4 on 2021-06-10 23:29

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0002_auto_20210610_1805'),
    ]

    operations = [
        migrations.CreateModel(
            name='Hub',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('ip', models.URLField()),
                ('category', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display_name', models.CharField(max_length=255, null=True)),
                ('aid', models.IntegerField()),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.AddIndex(
            model_name='hub',
            index=models.Index(fields=['id'], name='data_hub_id_055d65_idx'),
        ),
        migrations.AddField(
            model_name='accessory',
            name='hub',
            field=models.ForeignKey(default='2d881600-8fb2-4663-a12e-5ffca01539cf', on_delete=django.db.models.deletion.CASCADE, to='data.hub'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='channel',
            name='hub',
            field=models.ForeignKey(default='2d881600-8fb2-4663-a12e-5ffca01539cf', on_delete=django.db.models.deletion.CASCADE, to='data.hub'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='hardware',
            name='hub',
            field=models.ForeignKey(default='2d881600-8fb2-4663-a12e-5ffca01539cf', on_delete=django.db.models.deletion.CASCADE, to='data.hub'),
            preserve_default=False,
        ),
    ]
