{% extends "admin/base.html" %}

{% block title %}{% if subtitle %}{{ subtitle }} | {% endif %}{{ title }} |
    {{ site_title|default:_('Django site admin') }}{% endblock %}

{% block branding %}
    <h1 id="site-name"><a href="{% url 'admin:index' %}">{{ site_header|default:_('OpenHub') }}</a></h1>
{% endblock %}

{% block nav-global %}

    <div id="top_menu"><a
            href="/hubs/">Hubs</a> |
        <div class="dropdown">
            <button class="dropbtn">Dropdown
                <i class="fa fa-caret-down"></i>
            </button>
            <div class="dropdown-content">
                <li class="hub">

                    {% for hub in all_hubs %}
                        <h1>
                            <a href='/hub/{{ hub.id }}'>{{ hub.display_name }}</a>
                        </h1>
                    {% endfor %}
                </li>

            </div>
        </div>
        |
        <a href="/hardwares/">Hardware</a> | <a
                href="/accessories/">Accessories</a></div>
{% endblock %}
