# Generated by Django 3.2.4 on 2021-06-10 18:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('data', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='dht22',
            options={'base_manager_name': 'objects'},
        ),
        migrations.AlterModelOptions(
            name='mcp3008',
            options={'base_manager_name': 'objects'},
        ),
        migrations.AlterModelOptions(
            name='modprobe',
            options={'base_manager_name': 'objects'},
        ),
        migrations.AlterModelOptions(
            name='pipico',
            options={'base_manager_name': 'objects'},
        ),
        migrations.AlterModelOptions(
            name='veml7700',
            options={'base_manager_name': 'objects'},
        ),
        migrations.AddField(
            model_name='hardware',
            name='polymorphic_ctype',
            field=models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='polymorphic_data.hardware_set+', to='contenttypes.contenttype'),
        ),
    ]
