# Generated by Django 3.2.4 on 2021-06-11 21:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0006_accessorytype'),
    ]

    operations = [
        migrations.AddField(
            model_name='pipico',
            name='serial_com',
            field=models.CharField(max_length=100, null=True),
        ),
    ]
