# Generated by Django 3.2.5 on 2021-10-04 19:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0029_alter_datatransformer_parent'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='datatransformer',
            name='parent',
        ),
    ]
