{% extends './base_site.html' %}

{% block title %}{{ title }}{% endblock title %}

{% block content %}
    <h1>{{ title }}</h1>
    <input id="Start Hub" type="button" value="Start">
    <input id="Calibrate Hub" type="button" value="Calibrate">

{% endblock content %}