# Generated by Django 3.2.5 on 2021-10-03 03:11

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0026_auto_20211003_0308'),
    ]

    operations = [
        migrations.AddField(
            model_name='datatransformer',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='datatransformer',
            name='updated_at',
            field=models.DateTimeField(auto_now=True),
        ),
    ]
