# Generated by Django 3.2.4 on 2021-07-13 15:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0012_hardwareio_type'),
    ]

    operations = [
        migrations.RenameField(
            model_name='pwmio',
            old_name='pwm_pin',
            new_name='en',
        ),
        migrations.AddField(
            model_name='hardwareio',
            name='label',
            field=models.CharField(max_length=255, null=True),
        ),
    ]
