# Generated by Django 3.2.4 on 2021-07-12 19:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0008_auto_20210712_1649'),
    ]

    operations = [
        migrations.AddField(
            model_name='pigpio',
            name='channel_index',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='pipicoanalogio',
            name='pin',
            field=models.IntegerField(default=0),
            preserve_default=False,
        ),
    ]
