# Generated by Django 3.2.5 on 2021-08-14 18:02

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0016_auto_20210814_1801'),
    ]

    operations = [
        migrations.CreateModel(
            name='PMSA0031',
            fields=[
                ('hardware_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='data.hardware')),
                ('scl', models.IntegerField()),
                ('sda', models.IntegerField()),
                ('reset', models.IntegerField()),
            ],
            options={
                'abstract': False,
                'base_manager_name': 'objects',
            },
            bases=('data.hardware',),
        ),
    ]
