# Generated by Django 3.2.4 on 2021-06-11 18:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0004_category'),
    ]

    operations = [
        migrations.AlterField(
            model_name='category',
            name='enum',
            field=models.IntegerField(null=True),
        ),
    ]
