# Generated by Django 3.2.5 on 2021-08-14 18:01

from django.db import migrations
def gen(apps, schema_editor):
    from data.models.models import AccessoryType, HardwareChannelTypes, Category

    types = ['Camera']

    for type in types:
        cat = AccessoryType.objects.create()
        cat.type = type
        cat.save()



class Migration(migrations.Migration):

    dependencies = [
        ('data', '0015_auto_20210813_2336'),
    ]

    operations = [
        migrations.RunPython(gen, reverse_code=migrations.RunPython.noop),
    ]
