# Generated by Django 3.2.5 on 2021-10-06 17:45

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0038_auto_20211006_1745'),
    ]

    operations = [
        migrations.AlterField(
            model_name='datatransformerconstants',
            name='id',
            field=models.UUIDField(blank=True, default=uuid.UUID('254e53c8-9256-4f60-bf6e-42862dbd6a11'), primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='hardwarestatsdatatransformer',
            name='id',
            field=models.UUIDField(blank=True, default=uuid.UUID('9c02df0d-3861-4989-95af-89f4537f7393'), primary_key=True, serialize=False),
        ),
    ]
