# Generated by Django 3.2.5 on 2021-10-04 17:53

from django.db import migrations, models
import django.db.models.deletion
import mptt.fields


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0027_auto_20211003_0311'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='datatransformer',
            name='data_transformer_parent',
        ),
        migrations.AddField(
            model_name='datatransformer',
            name='level',
            field=models.PositiveIntegerField(default=1, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='datatransformer',
            name='lft',
            field=models.PositiveIntegerField(default=1, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='datatransformer',
            name='parent',
            field=mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='data.datatransformer'),
        ),
        migrations.AddField(
            model_name='datatransformer',
            name='rght',
            field=models.PositiveIntegerField(default=1, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='datatransformer',
            name='tree_id',
            field=models.PositiveIntegerField(db_index=True, default=1, editable=False),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='datatransformer',
            name='accessory',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='data.accessory'),
        ),
    ]
